%% TRUSS MODEL
%
% This script contains the model and probabilistic input definitions for
% the truss model.

%% 1 - INITIALIZE UQLAB
%
clearvars
uqlab

%% 2 - COMPUTATIONAL MODEL
%
% Create the computational model
ModelOpts.Name = 'trussResponseModel';
ModelOpts.mFile = 'uq_trussModelAnalytical';

myModel = uq_createModel(ModelOpts);
clear ModelOpts


%% 3 - PROBABILISTIC INPUT MODEL
%
for ii=1:2    
    InputOpts.Marginals(ii).Type = 'Lognormal';    
    InputOpts.Marginals(ii).Moments = [2.1e11 2.1e10];  
end

InputOpts.Marginals(3).Type = 'Lognormal';
InputOpts.Marginals(3).Moments = [2.0e-3 2.0e-4];

InputOpts.Marginals(4).Type = 'Lognormal';
InputOpts.Marginals(4).Moments = [1.0e-3 1.0e-4];

for ii=5:10    
    InputOpts.Marginals(ii).Type = 'Gumbel';    
    InputOpts.Marginals(ii).Moments = [5.0e4 7.5e3];  
end

% Variable names
InputOpts.Marginals(1).Name = 'E1';
InputOpts.Marginals(2).Name = 'E2';
InputOpts.Marginals(3).Name = 'A1';
InputOpts.Marginals(4).Name = 'A2';
InputOpts.Marginals(5).Name = 'P1';
InputOpts.Marginals(6).Name = 'P2';
InputOpts.Marginals(7).Name = 'P3';
InputOpts.Marginals(8).Name = 'P4';
InputOpts.Marginals(9).Name = 'P5';
InputOpts.Marginals(10).Name = 'P6';

myInput = uq_createInput(InputOpts);







